REST API subpackage
===================

.. automodule:: wa_kat.rest_api
    :members:
    :undoc-members:.
    :show-inheritance:

Submodules
----------

.. toctree::

   bottle_index
   keywords
   analyzers_api
   aleph_api
   virtual_fs
   to_output

.. toctree::

   shared
